from smollama_py import cli
from unittest.mock import patch
import pytest


def test_create_parser():

    parser = cli.create_parser()
    result = parser.parse_args([])
    assert result.mode == "chrome"

    result = parser.parse_args(["-m", "edge"])
    assert result.mode == "edge"


@patch("eel.start")
def test_mycommand(mock_eel_start):
    class Args:
        mode = "chrome"

    cli.mycommand(Args())
    mock_eel_start.assert_called_once_with(
        "index.html", size=(800, 600), close_callback=cli.close
    )


@patch("eel.start")
def test_mycommand_keyboard_interrupt(mock_eel_start):
    class Args:
        mode = "chrome"

    mock_eel_start.side_effect = KeyboardInterrupt
    with pytest.raises(SystemExit):
        cli.mycommand(Args())



import argparse
import eel
import sys
import os

public = os.path.join(os.path.dirname(__file__), "public")
# Initialize the Eel app
eel.init(public)


def create_parser():
    parser = argparse.ArgumentParser(description="A python app to serve smOllama")
    parser.add_argument(
        "-m", "--mode", choices=["chrome", "electron", "edge", "msie"], default="chrome"
    )
    return parser


def cli():
    "A python app to serve smOllama"
    parser = create_parser()
    args = parser.parse_args()
    mycommand(args)


def close(a, b):
    sys.exit(0)


def mycommand(args):
    try:
        eel.start("index.html", size=(800, 600), close_callback=close)
    except KeyboardInterrupt:
        sys.exit(0)
